@@ -6,7 +6,6 @@ from abc import ABC,abstractmethod
 
 import numpy as np
 import obsarray
-
 from punpy.digital_effects_table.digital_effects_table_templates import (
     DigitalEffectsTableTemplates,)
 from punpy.digital_effects_table.measurement_function_utils import (
@@ -36,6 +35,7 @@ class MeasurementFunction(ABC):
         corr_dims=-99,
         refxvar=None,
         sizes_dict=None,
+        use_err_corr_dict=False,
     ):
         """
         Initialise MeasurementFunction
@@ -64,6 +64,8 @@ class MeasurementFunction(ABC):
         :type refxvar: string, optional
         :param sizes_dict: Dictionary with sizes of each of the dimensions of the measurand. Defaults to None, in which cases sizes come from input quantites.
         :type sizes_dict: dict, optional
+        :param use_err_corr_dict: when possible, use dictionaries with separate error-correlation info per dimension in order to save memory
+        :type use_err_corr_dict: bool, optional
         """
         if prop is None:
             self.prop = MCPropagation(100, dtype="float32")
@@ -133,8 +135,11 @@ class MeasurementFunction(ABC):
             self.str_repeat_corr_dims,
             self.prop.verbose,
             self.templ,
+            use_err_corr_dict,
         )
 
+        self.use_err_corr_dict = use_err_corr_dict
+
     @abstractmethod
     def meas_function(self, *args, **kwargs):
         """
@@ -611,7 +616,7 @@ class MeasurementFunction(ABC):
         input_qty = self.utils.get_input_qty(
             args, expand=expand, sizes_dict=self.sizes_dict, ydims=self.ydims
         )
-        return self.meas_function(*input_qty)
+        return np.array(self.meas_function(*input_qty))
 
     def check_sizes_and_run(self, *args, expand=False, ds_out_pre=None):
         """
@@ -638,6 +643,7 @@ class MeasurementFunction(ABC):
 
         if self.sizes_dict is None:
             self.sizes_dict = {}
+            print(y.shape, self.ydims)
             for idim, dim in enumerate(self.ydims):
                 self.sizes_dict[dim] = y.shape[idim]
 
@@ -754,19 +760,38 @@ class MeasurementFunction(ABC):
         if all([iu is None for iu in input_unc]):
             return None, None
         else:
-            return self.prop.propagate_standard(
-                self.meas_function,
-                input_qty,
-                input_unc,
-                input_corr,
-                param_fixed=self.param_fixed,
-                corr_between=self.corr_between,
-                return_corr=return_corr,
-                return_samples=False,
-                repeat_dims=self.num_repeat_dims,
-                corr_dims=self.num_corr_dims,
-                output_vars=self.output_vars,
-            )
+            if self.use_err_corr_dict:
+                MC_x = self.prop.generate_MC_sample(
+                    input_qty,
+                    input_unc,
+                    corr_x=input_corr,
+                    corr_between=self.corr_between,
+                    comp_list=True,
+                )
+                MC_y = self.prop.run_samples(
+                    self.meas_function, MC_x, output_vars=self.output_vars
+                )
+                return self.prop.process_samples(
+                    MC_x,
+                    MC_y,
+                    return_corr=return_corr,
+                    corr_dims=self.num_corr_dims,
+                    output_vars=self.output_vars,
+                )
+            else:
+                return self.prop.propagate_standard(
+                    self.meas_function,
+                    input_qty,
+                    input_unc,
+                    input_corr,
+                    param_fixed=self.param_fixed,
+                    corr_between=self.corr_between,
+                    return_corr=return_corr,
+                    return_samples=False,
+                    repeat_dims=self.num_repeat_dims,
+                    corr_dims=self.num_corr_dims,
+                    output_vars=self.output_vars,
+                )
 
     def propagate_random(self, *args, expand=False):
         """
@@ -864,19 +889,38 @@ class MeasurementFunction(ABC):
         if all([iu is None for iu in input_unc]):
             return None, None
         else:
-            return self.prop.propagate_standard(
-                self.meas_function,
-                input_qty,
-                input_unc,
-                input_corr,
-                param_fixed=self.param_fixed,
-                corr_between=self.corr_between,
-                return_corr=return_corr,
-                return_samples=False,
-                repeat_dims=self.num_repeat_dims,
-                corr_dims=self.num_corr_dims,
-                output_vars=self.output_vars,
-            )
+            if self.use_err_corr_dict:
+                MC_x = self.prop.generate_MC_sample(
+                    input_qty,
+                    input_unc,
+                    corr_x=input_corr,
+                    corr_between=self.corr_between,
+                    comp_list=True,
+                )
+                MC_y = self.prop.run_samples(
+                    self.meas_function, MC_x, output_vars=self.output_vars
+                )
+                return self.prop.process_samples(
+                    MC_x,
+                    MC_y,
+                    return_corr=return_corr,
+                    corr_dims=self.num_corr_dims,
+                    output_vars=self.output_vars,
+                )
+            else:
+                return self.prop.propagate_standard(
+                    self.meas_function,
+                    input_qty,
+                    input_unc,
+                    input_corr,
+                    param_fixed=self.param_fixed,
+                    corr_between=self.corr_between,
+                    return_corr=return_corr,
+                    return_samples=False,
+                    repeat_dims=self.num_repeat_dims,
+                    corr_dims=self.num_corr_dims,
+                    output_vars=self.output_vars,
+                )
 
     def propagate_specific(self, form, *args, expand=False, return_corr=False):
         """
@@ -907,16 +951,34 @@ class MeasurementFunction(ABC):
         if all([iu is None for iu in input_unc]):
             return None, None
         else:
-            return self.prop.propagate_standard(
-                self.meas_function,
-                input_qty,
-                input_unc,
-                input_corr,
-                param_fixed=self.param_fixed,
-                corr_between=self.corr_between,
-                return_corr=return_corr,
-                return_samples=False,
-                repeat_dims=self.num_repeat_dims,
-                corr_dims=self.num_corr_dims,
-                output_vars=self.output_vars,
-            )
+            if self.use_err_corr_dict:
+                MC_x = self.prop.generate_MC_sample(
+                    input_qty,
+                    input_unc,
+                    corr_x=input_corr,
+                    corr_between=self.corr_between,
+                )
+                MC_y = self.prop.run_samples(
+                    self.meas_function, MC_x, output_vars=self.output_vars
+                )
+                ufd, ucorrd, corr_out = self.prop.process_samples(
+                    MC_x,
+                    MC_y,
+                    return_corr=return_corr,
+                    corr_dims=self.num_corr_dims,
+                    output_vars=self.output_vars,
+                )
+            else:
+                return self.prop.propagate_standard(
+                    self.meas_function,
+                    input_qty,
+                    input_unc,
+                    input_corr,
+                    param_fixed=self.param_fixed,
+                    corr_between=self.corr_between,
+                    return_corr=return_corr,
+                    return_samples=False,
+                    repeat_dims=self.num_repeat_dims,
+                    corr_dims=self.num_corr_dims,
+                    output_vars=self.output_vars,
+                )
