@@ -7,6 +7,7 @@ import unittest
 import comet_maths as cm
 import numpy as np
 import numpy.testing as npt
+
 from punpy.mc.mc_propagation import MCPropagation
 
 """___Authorship___"""
@@ -37,6 +38,13 @@ yerr_corr = 2 ** 0.5 * np.ones(200)
 def functionb(x1, x2):
     return 2 * x1 - x2
 
+def functionb_fail(x1, x2):
+    rand=np.random.random()
+    if rand<0.1:
+        return None
+    else:
+        return 2 * x1 - x2
+
 
 x1b = np.ones((20, 30)) * 50
 x2b = np.ones((20, 30)) * 30
@@ -724,6 +732,14 @@ class TestMCPropagation(unittest.TestCase):
         npt.assert_allclose(ufd[0], yerr_uncorrd[0], rtol=0.06)
         npt.assert_allclose(ufd[1], yerr_uncorrd[1], rtol=0.06)
 
+    def test_failed_processing(self):
+        prop = MCPropagation(10000, parallel_cores=4,verbose=True)
+        ufb, ucorrb = prop.propagate_random(
+            functionb_fail, xsb, xerrsb, return_corr=True
+        )
+        npt.assert_allclose(ucorrb, np.eye(len(ucorrb)), atol=0.06)
+        npt.assert_allclose(ufb, yerr_uncorrb, rtol=0.06)
+
     def test_perform_checks(self):
         prop = MCPropagation(20000)
         corrc = [
